/* ----------------------------------------------------------
                           smallio.c

     Header fuer sehr schlankes I/O Interface ueber die
     serielle  Schnittstelle mit abgespecktem printf.
     Hierdurch ist es moeglich, die Beispiele der Hilfedatei
     fuer viele Mikrocontroller und auf PC nachzuvollziehen.

     Fuer die unterstuetzten Microcontroller (AVR, STM32,
     MCS-51, STM8) ist jeweils ein eigenes smallio
     verfuegbar, sodass JEDES Programm lediglich im Header
     ein

                  "include smallio.h"

     eingefuegt werden muss. Im Makefile ist einzustellen,
     dass smallio.o fuer AVR,ARM und PC-Konsolenprogramme
     oder smallio.rel fuer  MCS-51 und STM8) hinzugelinkt
     werden muss. Eintrag im Makefile:

     SRCS      += ../src/smallio.o

     Die eingestellte Baudrate betraegt bei allen
     Controllern 19200 bd (Ausnahme MCS-51, hier dann
     4800 bd)

     Protokoll ist 8N1

     ------------------------------------------------------

     Von smallio Unterstuetzte Controller in der
     STM8 - Version:

     STM8S003, S103, S105

     03.02.2020  R. Seelig
   ---------------------------------------------------------- */

#ifndef in_smallio
  #define in_smallio

  #include <stdint.h>
  #include <stdlib.h>
  #include <stdbool.h>
  #include <stdarg.h>

  #include "stm8s.h"
  #include "stm8_gpio.h"


  #define echo_enable     0
  #define readint_enable  1

  extern char printfkomma;

  #define use_usart             1                           // 1 fuer STM8S103
                                                            // 2 fuer STM8S105

  #define BAUDRATE       19200u


  /* -----------------------------------------------------------------------
                                  Prototypen
     ----------------------------------------------------------------------- */
  // UART
  void uart_init(void);
  void putchar(char ch);
  uint8_t getchar( void );
  uint8_t keypressed( void );

  #if (readint_enable == 1)

    int16_t readint();

  #endif

  // PRINTF
  void putint(int16_t i, char komma);
  void hexnibbleout(uint8_t b);
  void puthex(uint16_t h);
  void my_putramstring(uint8_t *p);
  void my_printf(const char *s,...);

  #define printf                my_printf

  // System
  void smallio_init(void);
  void delay(uint16_t cnt);
  void delay_us(uint16_t cnt);
  void int_enable(void);
  void int_disable(void);

#endif
