/* -----------------------------------------------------
                        smallio_printf_demo.c

    Demonstriert die printf-Faehigkeiten von smallio.

    Dies hier ist die Demo fuer "Anfaenger" die ein
    erstes Erfolgserlebnis suchen. Hier muss sich noch
    nicht sehr mit der Hardware auseinandergesetzt
    werden (noch nicht).

    Eine einzige Angabe von

                  #include "smallio.h"

    und ein

                  smallio_init();

    in der Main-Funktion initialiseren ein einfaches
    System, bei dem ein Einrichten von Portpins mittels
    Bitbanging extrem einfach ist. Zudem wird die
    serielle Schnittstelle initialisiert und ein einfache
    printf-Funktion zur Verfuegung gestellt.

    SMALLIO ist auch fuer STM32, MCS51 und NXP-
    Controller verfuegbar

    MCU       : STM8S003 / S103 / S105
    Takt      : 16 MHz intern

    03.02.2020   R. Seelig
  ------------------------------------------------------ */


#include "smallio.h"            // ein einfaches Ein- Ausgabesystem

// Festlegen von LED-Anschluss und Taster

// Onboard-LED auf dem minimalistischen Developmentboard (China) ist PB5

#define led_init()     PB5_output_init()
#define led_on()       PB5_set()
#define led_off()      PB5_clr()


// Onboard-LED auf dem r3 -Board ist PC2
/*
#define led_init()     PC2_output_init()
#define led_set()      PC2_set()
#define led_clr()      PC2_clr()
*/

#define tast_init()     PB0_input_init()
#define is_tast()       is_PB0()


/* -----------------------------------------------------
                             main
   ----------------------------------------------------- */
int main(void)
{
  uint16_t       counter = 3121;
  int            zahl;
  uint16_t       ch;

  smallio_init();                         // System initialisieren

  led_init();                             // Anschluss der LED konfigurieren
  tast_init();                            // Anschluss Taste konfigurieren

  printfkomma= 2;                         // bei Pseudokommazahlen 2 Nachkommastellen

  printf("\n\r-------------------------------------\n\r");
  printf("\n\r STM8S / 16 MHz 19200bd 8N1");
  printf("\n\r Februar 2020 R. Seelig \n\r");
  printf("\n\r-------------------------------------\n\r");
  printf("\n\rEin 16-Bit Integer  : %d",counter);
  printf("\n\rEine Festkommazahl  : %k",8213);
  printf("\n\rEine 16-Bit Hexzahl : %x",0xca4b);

  // Funktionalitaetstest Zahleneingabe
  printf("\n\n\r Zahleneingabe: ");
  zahl= readint();
  printf("\n\r die Zahl war      : %d", zahl);

  printf("\n\rTaste fuer Counterstop... \n\n\r");

  while(keypressed()) {ch= getchar(); putchar(ch); }   // eventuell eingegangene Zeichen: alle loeschen

  // Zaehlerschleife mit LED-Blinken
  while (1)
  {
    led_off();
    delay(500);
    led_on();

    printf("  Counter: %xh  Taster= ", counter);

    if (is_tast()) printf("1     \r");
            else printf("0     \r");

    delay(500);
    counter++;
    counter = counter % 3600;

    if (keypressed())
    {
      ch= getchar();
      printf("\n\n\rGedrueckte Taste war: %c\n\r", ch );
      printf("Beliebige Taste fuer Counterstart...\n\n\r");
      ch= getchar();

    }
  }
}
